Learn R Programming

TSQCA (version 1.3.1)

TSQCA-package: TSQCA: Threshold Sweep Extensions for Qualitative Comparative Analysis

Description

Provides threshold sweep methods for Qualitative Comparative Analysis (QCA). Implements Condition Threshold Sweep-Single (CTS-S), Condition Threshold Sweep-Multiple (CTS-M), Outcome Threshold Sweep (OTS), and Dual Threshold Sweep (DTS) for systematic exploration of threshold calibration effects on crisp-set QCA results. These methods extend traditional robustness approaches by treating threshold variation as an exploratory tool for discovering causal structures. Built on top of the 'QCA' package by Dusa (2019) tools:::Rd_expr_doi("10.1007/978-3-319-75668-4"), with function arguments following 'QCA' conventions. Based on set-theoretic methods by Ragin (2008) tools:::Rd_expr_doi("10.7208/chicago/9780226702797.001.0001") and established robustness protocols by Rubinson et al. (2019) tools:::Rd_expr_doi("10.1177/00491241211036158").

Arguments

Author

Maintainer: Yuki Toyoda yuki.toyoda.ds@hosei.ac.jp

Other contributors:

  • Japan Society for the Promotion of Science (KAKENHI Grant Number JP20K01998) [funder]

See Also

Useful links: