View source: R/tsqca_config_chart.R
| config_chart_from_paths | R Documentation |
A simpler interface for generating configuration charts when you have paths directly (without a full QCA solution object).
config_chart_from_paths(
paths,
symbol_set = c("unicode", "ascii", "latex"),
language = c("en", "ja"),
condition_order = NULL,
n_sol = 1L,
solution_note = TRUE,
solution_note_style = c("simple", "detailed"),
epi_list = NULL
)
paths |
Character vector. Paths in QCA notation (e.g., "A*B*~C"). |
symbol_set |
Character. One of |
language |
Character. |
condition_order |
Character vector. Optional ordering of conditions. |
n_sol |
Integer. Number of equivalent solutions. If > 1, a note is added explaining that multiple solutions exist and M1 is shown. Default is 1. |
solution_note |
Logical. Whether to add solution note when n_sol > 1. Default is TRUE. |
solution_note_style |
Character. |
epi_list |
Character vector. Essential prime implicants for detailed notes.
Only used when |
Character string containing Markdown-formatted table.
# Simple usage with paths
paths <- c("A*B", "A*C*~D", "B*E")
chart <- config_chart_from_paths(paths)
cat(chart)
# With ASCII symbols
chart <- config_chart_from_paths(paths, symbol_set = "ascii")
cat(chart)
# With multiple solution note
chart <- config_chart_from_paths(paths, n_sol = 2)
cat(chart)
# With detailed note including EPIs
chart <- config_chart_from_paths(
paths, n_sol = 2,
solution_note_style = "detailed",
epi_list = c("A*B")
)
cat(chart)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.