generate_term_level_chart: Generate solution-term level chart (Fiss-style)

View source: R/tsqca_config_chart.R

generate_term_level_chartR Documentation

Generate solution-term level chart (Fiss-style)

Description

Creates a configuration chart where each column represents a single prime implicant (configuration), following Fiss (2011) notation.

Usage

generate_term_level_chart(sum_df, conditions, symbols, language = "en")

Arguments

sum_df

Data frame. Summary data frame from sweep results with expression column and threshold column(s).

conditions

Character vector. Condition names for row ordering.

symbols

List. Symbol set (present, absent) for the chart.

language

Character. Language for labels ("en" or "ja").

Value

Character string containing Markdown-formatted table.


TSQCA documentation built on Feb. 18, 2026, 5:06 p.m.