identify_epi: Identify Essential Prime Implicants from multiple solutions

View source: R/tsqca_config_chart.R

identify_epiR Documentation

Identify Essential Prime Implicants from multiple solutions

Description

Finds terms that appear in ALL solutions (EPIs) versus terms that appear in only some solutions (SPIs).

Usage

identify_epi(solutions)

Arguments

solutions

List of solution vectors. Each element is a character vector of terms for one solution.

Value

List with:

  • epi — Essential prime implicants (in all solutions)

  • spi — Selective prime implicants (in some solutions)

  • n_solutions — Number of solutions

Examples

solutions <- list(
  c("A*B", "C", "D"),
  c("A*B", "C", "E"),
  c("A*B", "C", "F")
)
result <- identify_epi(solutions)
# result$epi = c("A*B", "C")
# result$spi = c("D", "E", "F")


TSQCA documentation built on Feb. 18, 2026, 5:06 p.m.