Learn R Programming

TSQCA (version 1.3.1)

summary.tsqca_result: Summary method for TSQCA results

Description

Displays detailed results table with solution formulas and fit measures.

Usage

# S3 method for tsqca_result
summary(object, ...)

# S3 method for otSweep_result summary(object, ...)

# S3 method for dtSweep_result summary(object, ...)

# S3 method for ctSweepS_result summary(object, ...)

# S3 method for ctSweepM_result summary(object, ...)

Value

Invisibly returns object.

Arguments

object

A TSQCA result object returned by one of the sweep functions.

...

Additional arguments (ignored).

Examples

Run this code
# \donttest{
data(sample_data)
result <- otSweep(
  dat = sample_data,
  outcome = "Y",
  conditions = c("X1", "X2", "X3"),
  sweep_range = 6:8,
  thrX = c(X1 = 7, X2 = 7, X3 = 7)
)
summary(result)
# }

Run the code above in your browser using DataLab