View source: R/tsqca_config_chart.R
| identify_epi | R Documentation |
Finds terms that appear in ALL solutions (EPIs) versus terms that appear in only some solutions (SPIs).
identify_epi(solutions)
solutions |
List of solution vectors. Each element is a character vector of terms for one solution. |
List with:
epi — Essential prime implicants (in all solutions)
spi — Selective prime implicants (in some solutions)
n_solutions — Number of solutions
solutions <- list(
c("A*B", "C", "D"),
c("A*B", "C", "E"),
c("A*B", "C", "F")
)
result <- identify_epi(solutions)
# result$epi = c("A*B", "C")
# result$spi = c("D", "E", "F")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.